.. include:: /_includes/wip_prolog.rst

:mod:`stix.ttp.malware_instance` Module
=======================================

.. module:: stix.ttp.malware_instance

Classes
-------

.. autoclass:: MalwareInstance
	:show-inheritance:
	:members:

Functions
---------

.. autofunction:: add_extension

Constants
---------

.. autodata:: _EXTENSION_MAP
